@@ -3,11 +3,13 @@ package Test::Lazy::Template;
 use strict;
 use warnings;
 
-use base qw/Class::Accessor Exporter/;
-__PACKAGE__->mk_accessors(qw/_template/);
+use base qw/Class::Accessor::Fast/;
 
-use Test::Lazy qw/try/;
+__PACKAGE__->mk_accessors(qw/tester template/);
+
+use Test::Lazy::Tester;
 use Test::Builder();
+use Scalar::Util qw/blessed/;
 use Carp;
 
 =head1 NAME
@@ -50,13 +52,11 @@ The best way to show this is in an example:
 		[ is => { 0 => 0, 1 => 2, 2 => 4, 3 => 6, 4 => 8 } ],
 	]);
 
-=over 4
+=head1 METHODS
 
-=cut
+=head2 Test::Lazy::Template->new( <template> )
 
-=item Test::Lazy::Template->new( <template> )
-
-=item Test::Lazy::Template->new( <test>, <test>, ..., <test> )
+=head2 Test::Lazy::Template->new( <test>, <test>, ..., <test> )
 
 Create a new C<Test::Lazy::Template> object using the giving test specification.
 
@@ -83,6 +83,7 @@ Returns the new C<Test::Lazy::Template> object
 
 sub new {
 	my $self = bless {}, shift;
+    my $tester = blessed $_[0] && $_[0]->isa("Test::Lazy::Tester") ? shift : Test::Lazy::Tester->new;
 	my $template = $_[0];
 	if (ref $template eq 'SCALAR') {
 		my @template = map { [ $_ ] } grep { length $_ && $_ !~ m/^\s*#/ } split m/\n/, $$template;
@@ -93,15 +94,16 @@ sub new {
 	else {
 		$template = [ @_ ];
 	}
-	$self->_template($template);
+	$self->tester($tester);
+	$self->template($template);
 	return $self;
 }
 
-=item $template->test( <template> )
+=head2 $template->test( <template> )
 
 For each test in $template, modify and run each the test according to the corresponding entry in <template>.
 
-=item $template->test( <test> )
+=head2 $template->test( <test> )
 
 Modify and then run each test in $template by using <test> to complete each test's specification.
 
@@ -110,7 +112,7 @@ Modify and then run each test in $template by using <test> to complete each test
 sub test {
 	my $self = shift;
 
-	my $template = $self->_template;
+	my $template = $self->template;
 	my $size = @$template;
 	my $mdf_template;
 	my $base_stmt;
@@ -157,18 +159,12 @@ sub test {
 		my ($rslt) = grep { defined } ($mdf_rslt, $line->[2]);
 
 		{
-			local $Test::Builder::Level = $Test::Builder::Level ? $Test::Builder::Level + 2 : 2;
+			local $Test::Builder::Level = $Test::Builder::Level + 1;
 
-			try($stmt, $cmpr, $rslt, "$index: %");
+			$self->tester->try($stmt, $cmpr, $rslt, "$index: %");
 		}
 	}
 
 }
 
-=pod
-
-=back
-
-=cut
-
 1;
